pub fn from_json<T: DeserializeOwned>(bytes: &[u8]) -> Result<T>Expand description
Deserialize a JSON body from the wire into a typed value.
pub fn from_json<T: DeserializeOwned>(bytes: &[u8]) -> Result<T>Deserialize a JSON body from the wire into a typed value.